==> haskell-cabal-install-solver-3.8.1.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-solver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install-solver
version:              3.8.1.0
visibility:           public
id:                   cabal-install-solver-3.8.1.0-GP1WXL5O8565DytwK7gPGj
key:                  cabal-install-solver-3.8.1.0-GP1WXL5O8565DytwK7gPGj
license:              BSD-3-Clause
copyright:            2003-2022, Cabal Development Team
maintainer:           Cabal Development Team <cabal-devel@haskell.org>
author:               Cabal Development Team (see AUTHORS file)
homepage:             http://www.haskell.org/cabal/
synopsis:             The command-line interface for Cabal and Hackage.
description:
    The solver component used in cabal-install command-line program

category:             Distribution
abi:                  9e80bbd66bb5ad04b54c5ce9d7d59f7b
exposed:              True
exposed-modules:
    Distribution.Client.Utils.Assertion
    Distribution.Solver.Compat.Prelude Distribution.Solver.Modular
    Distribution.Solver.Modular.Assignment
    Distribution.Solver.Modular.Builder
    Distribution.Solver.Modular.Configured
    Distribution.Solver.Modular.ConfiguredConversion
    Distribution.Solver.Modular.ConflictSet
    Distribution.Solver.Modular.Cycles
    Distribution.Solver.Modular.Dependency
    Distribution.Solver.Modular.Explore
    Distribution.Solver.Modular.Flag Distribution.Solver.Modular.Index
    Distribution.Solver.Modular.IndexConversion
    Distribution.Solver.Modular.LabeledGraph
    Distribution.Solver.Modular.Linking Distribution.Solver.Modular.Log
    Distribution.Solver.Modular.Message
    Distribution.Solver.Modular.MessageUtils
    Distribution.Solver.Modular.PSQ Distribution.Solver.Modular.Package
    Distribution.Solver.Modular.Preference
    Distribution.Solver.Modular.RetryLog
    Distribution.Solver.Modular.Solver Distribution.Solver.Modular.Tree
    Distribution.Solver.Modular.Validate
    Distribution.Solver.Modular.Var Distribution.Solver.Modular.Version
    Distribution.Solver.Modular.WeightedPSQ
    Distribution.Solver.Types.ComponentDeps
    Distribution.Solver.Types.ConstraintSource
    Distribution.Solver.Types.DependencyResolver
    Distribution.Solver.Types.Flag
    Distribution.Solver.Types.InstSolverPackage
    Distribution.Solver.Types.InstalledPreference
    Distribution.Solver.Types.LabeledPackageConstraint
    Distribution.Solver.Types.OptionalStanza
    Distribution.Solver.Types.PackageConstraint
    Distribution.Solver.Types.PackageFixedDeps
    Distribution.Solver.Types.PackageIndex
    Distribution.Solver.Types.PackagePath
    Distribution.Solver.Types.PackagePreferences
    Distribution.Solver.Types.PkgConfigDb
    Distribution.Solver.Types.Progress
    Distribution.Solver.Types.ResolverPackage
    Distribution.Solver.Types.Settings
    Distribution.Solver.Types.SolverId
    Distribution.Solver.Types.SolverPackage
    Distribution.Solver.Types.SourcePackage
    Distribution.Solver.Types.Variable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-solver
hs-libraries:         HScabal-install-solver-3.8.1.0-GP1WXL5O8565DytwK7gPGj
depends:
    Cabal-3.8.1.0 Cabal-syntax-3.8.1.0 array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    edit-distance-0.2.2.1-G1yLeTPfmZ3Ktu5xHNig1C filepath-1.4.2.2
    mtl-2.2.2 pretty-1.1.3.6 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-solver/html/cabal-install-solver.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-solver/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-install-solver-3.8.1.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-install-solver.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-install-solver
version:              3.8.1.0
visibility:           public
id:                   cabal-install-solver-3.8.1.0-APuKeFtXq9e4AXuamGkPxK
key:                  cabal-install-solver-3.8.1.0-APuKeFtXq9e4AXuamGkPxK
license:              BSD-3-Clause
copyright:            2003-2022, Cabal Development Team
maintainer:           Cabal Development Team <cabal-devel@haskell.org>
author:               Cabal Development Team (see AUTHORS file)
homepage:             http://www.haskell.org/cabal/
synopsis:             The command-line interface for Cabal and Hackage.
description:
    The solver component used in cabal-install command-line program

category:             Distribution
abi:                  ca0bccbf9739f43b5f1ed2915b09a13c
exposed:              True
exposed-modules:
    Distribution.Client.Utils.Assertion
    Distribution.Solver.Compat.Prelude Distribution.Solver.Modular
    Distribution.Solver.Modular.Assignment
    Distribution.Solver.Modular.Builder
    Distribution.Solver.Modular.Configured
    Distribution.Solver.Modular.ConfiguredConversion
    Distribution.Solver.Modular.ConflictSet
    Distribution.Solver.Modular.Cycles
    Distribution.Solver.Modular.Dependency
    Distribution.Solver.Modular.Explore
    Distribution.Solver.Modular.Flag Distribution.Solver.Modular.Index
    Distribution.Solver.Modular.IndexConversion
    Distribution.Solver.Modular.LabeledGraph
    Distribution.Solver.Modular.Linking Distribution.Solver.Modular.Log
    Distribution.Solver.Modular.Message
    Distribution.Solver.Modular.MessageUtils
    Distribution.Solver.Modular.PSQ Distribution.Solver.Modular.Package
    Distribution.Solver.Modular.Preference
    Distribution.Solver.Modular.RetryLog
    Distribution.Solver.Modular.Solver Distribution.Solver.Modular.Tree
    Distribution.Solver.Modular.Validate
    Distribution.Solver.Modular.Var Distribution.Solver.Modular.Version
    Distribution.Solver.Modular.WeightedPSQ
    Distribution.Solver.Types.ComponentDeps
    Distribution.Solver.Types.ConstraintSource
    Distribution.Solver.Types.DependencyResolver
    Distribution.Solver.Types.Flag
    Distribution.Solver.Types.InstSolverPackage
    Distribution.Solver.Types.InstalledPreference
    Distribution.Solver.Types.LabeledPackageConstraint
    Distribution.Solver.Types.OptionalStanza
    Distribution.Solver.Types.PackageConstraint
    Distribution.Solver.Types.PackageFixedDeps
    Distribution.Solver.Types.PackageIndex
    Distribution.Solver.Types.PackagePath
    Distribution.Solver.Types.PackagePreferences
    Distribution.Solver.Types.PkgConfigDb
    Distribution.Solver.Types.Progress
    Distribution.Solver.Types.ResolverPackage
    Distribution.Solver.Types.Settings
    Distribution.Solver.Types.SolverId
    Distribution.Solver.Types.SolverPackage
    Distribution.Solver.Types.SourcePackage
    Distribution.Solver.Types.Variable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cabal-install-solver-3.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-install-solver
hs-libraries:         HScabal-install-solver-3.8.1.0-APuKeFtXq9e4AXuamGkPxK
depends:
    Cabal-3.8.1.0 Cabal-syntax-3.8.1.0 array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    edit-distance-0.2.2.1-E5e3pagBtOWW2EaJ6XDmJ filepath-1.4.2.2
    mtl-2.2.2 pretty-1.1.3.6 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-solver/html/cabal-install-solver.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-solver/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
